==> nadiv_2.10.tar.gz: nadiv/src/dijp.cc <==
#include "dij.h"

extern "C"{  

void dijp(
	int *dam,
	int *sire,
	int *lAr,
	int *indk,
        int *indj,
	int *iAP,     
	int *pAP,	         
	double *xAP,
	double *dij
){         

  int     k, j, m, kDam, kSire, jDam, jSire;
  double rmmp, rffp, rmfp, rfmp, dij_tmp;

  for(k = 0; k < lAr[0]; k++){ 
    kDam = dam[indk[k]];
    kSire = sire[indk[k]];
    if(kDam != -999 & kSire != -999){
       if(indk[k] != indj[k]){ 
         jDam = dam[indj[k]];
         jSire = sire[indj[k]];
         if(jDam != -999 & jSire != -999){
           rmfp = 0.0;
           rmmp = 0.0;
           rfmp = 0.0;
           rffp = 0.0;
           for(m = pAP[max(kDam, jSire)]; m < pAP[max(kDam, jSire)+1]; m++){
             if(iAP[m] == min(kDam, jSire)){
               rmfp += xAP[m];
             }
             if(rmfp != 0.0){
                break;
             }
           }

           for(m = pAP[max(kDam, jDam)]; m < pAP[max(kDam, jDam)+1]; m++){
             if(iAP[m] == min(kDam, jDam)){
               rmmp += xAP[m];
             }
             if(rmmp != 0.0){
                break;
             }
           }

           for(m = pAP[max(kSire, jDam)]; m < pAP[max(kSire, jDam)+1]; m++){  
             if(iAP[m] == min(kSire, jDam)){
               rfmp += xAP[m];
             }
             if(rfmp != 0.0){
	        break;
             }
           }

           for(m = pAP[max(kSire, jSire)]; m < pAP[max(kSire, jSire)+1]; m++){
             if(iAP[m] == min(kSire, jSire)){
               rffp += xAP[m];
             }
             if(rffp != 0.0){
                break;
             }
           }


           dij_tmp = (rmmp*rffp) + (rmfp*rfmp);
           if(dij_tmp != 0.0){
              dij[k] = dij_tmp;   
           }   
         }
       }   
    }   
  }   
                    
}
}

==> nadiv_2.12.tar.gz: nadiv/src/dijp.cc <==
#include "dij.h"

extern "C"{  

void dijp(
	int *dam,
	int *sire,
	int *lAr,
	int *indk,
        int *indj,
	int *iAP,     
	int *pAP,	         
	double *xAP,
	double *dij
){         

  int     k, m, kDam, kSire, jDam, jSire;
  double rmmp, rffp, rmfp, rfmp, dij_tmp;

  for(k = 0; k < lAr[0]; k++){ 
    kDam = dam[indk[k]];
    kSire = sire[indk[k]];
    if((kDam != -999) & (kSire != -999)){
       if(indk[k] != indj[k]){ 
         jDam = dam[indj[k]];
         jSire = sire[indj[k]];
         if((jDam != -999) & (jSire != -999)){
           rmfp = 0.0;
           rmmp = 0.0;
           rfmp = 0.0;
           rffp = 0.0;
           for(m = pAP[max(kDam, jSire)]; m < pAP[max(kDam, jSire)+1]; m++){
             if(iAP[m] == min(kDam, jSire)){
               rmfp += xAP[m];
             }
             if(rmfp != 0.0){
                break;
             }
           }

           for(m = pAP[max(kDam, jDam)]; m < pAP[max(kDam, jDam)+1]; m++){
             if(iAP[m] == min(kDam, jDam)){
               rmmp += xAP[m];
             }
             if(rmmp != 0.0){
                break;
             }
           }

           for(m = pAP[max(kSire, jDam)]; m < pAP[max(kSire, jDam)+1]; m++){  
             if(iAP[m] == min(kSire, jDam)){
               rfmp += xAP[m];
             }
             if(rfmp != 0.0){
	        break;
             }
           }

           for(m = pAP[max(kSire, jSire)]; m < pAP[max(kSire, jSire)+1]; m++){
             if(iAP[m] == min(kSire, jSire)){
               rffp += xAP[m];
             }
             if(rffp != 0.0){
                break;
             }
           }


           dij_tmp = (rmmp*rffp) + (rmfp*rfmp);
           if(dij_tmp != 0.0){
              dij[k] = dij_tmp;   
           }   
         }
       }   
    }   
  }   
                    
}
}
